@@ -4,20 +4,8 @@
  *
  * This file is part of GNU Radio
  *
- * GNU Radio is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNU Radio is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNU Radio; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifndef INCLUDED_QTGUI_TIME_RASTER_SINK_F_H
@@ -60,7 +48,7 @@ class QTGUI_API time_raster_sink_f : virtual public sync_block
 {
 public:
     // gr::qtgui::time_raster_sink_f::sptr
-    typedef boost::shared_ptr<time_raster_sink_f> sptr;
+    typedef std::shared_ptr<time_raster_sink_f> sptr;
 
     /*!
      * \brief Build a floating point time raster sink.
@@ -92,9 +80,13 @@ public:
     virtual void* pyqwidget() = 0;
 #endif
 
+    virtual void set_x_label(const std::string& label) = 0;
+    virtual void set_x_range(double start, double end) = 0;
+    virtual void set_y_label(const std::string& label) = 0;
+    virtual void set_y_range(double start, double end) = 0;
     virtual void set_update_time(double t) = 0;
     virtual void set_title(const std::string& title) = 0;
-    virtual void set_line_label(unsigned int which, const std::string& lable) = 0;
+    virtual void set_line_label(unsigned int which, const std::string& label) = 0;
     virtual void set_line_color(unsigned int which, const std::string& color) = 0;
     virtual void set_line_width(unsigned int which, int width) = 0;
     virtual void set_line_style(unsigned int which, Qt::PenStyle style) = 0;
